@@ -31,15 +31,10 @@
 #include <stdio.h>
 
 #define NV_MAX_CHARACTER_DEVICE_FILE_STRLEN  128
-#define NV_MODULE_INSTANCE_NONE              -1
-#define NV_MODULE_INSTANCE_ZERO              0
-#define NV_MAX_MODULE_INSTANCES              8
 #define NV_CTL_DEVICE_NUM                    255
 #define NV_MODESET_MINOR_DEVICE_NUM          254
 #define NV_NVSWITCH_CTL_MINOR                255
 
-#define NV_FRONTEND_CONTROL_DEVICE_MINOR_MAX NV_CTL_DEVICE_NUM
-
 #define NV_DEVICE_FILE_PATH "/dev/nvidia%d"
 #define NV_CTRL_DEVICE_FILE_PATH "/dev/nvidiactl"
 #define NV_MODESET_DEVICE_NAME "/dev/nvidia-modeset"
@@ -48,16 +43,6 @@
 #define NV_NVSWITCH_CTL_NAME "/dev/nvidia-nvswitchctl"
 #define NV_NVSWITCH_DEVICE_NAME "/dev/nvidia-nvswitch%d"
 
-#define NV_NMODULE_CTRL_DEVICE_FILE_PATH "/dev/nvidiactl%d"
-
-#define NV_FRONTEND_CONTROL_DEVICE_MINOR_MIN \
-    (NV_FRONTEND_CONTROL_DEVICE_MINOR_MAX - \
-     NV_MAX_MODULE_INSTANCES)
-
-#define NV_FRONTEND_IS_CONTROL_DEVICE(x) \
-    ((x <= NV_FRONTEND_CONTROL_DEVICE_MINOR_MAX) && \
-     (x > NV_FRONTEND_CONTROL_DEVICE_MINOR_MIN))
-
 #if defined(NV_LINUX)
 
 typedef enum
@@ -79,9 +64,9 @@ static __inline__ int nvidia_test_file_state(int state,
     return !!(state & (1 << value));
 }
 
-int nvidia_get_file_state(int minor, int module_instance);
-int nvidia_modprobe(const int print_errors, int module_instance);
-int nvidia_mknod(int minor, int module_instance);
+int nvidia_get_file_state(int minor);
+int nvidia_modprobe(const int print_errors);
+int nvidia_mknod(int minor);
 int nvidia_uvm_modprobe(void);
 int nvidia_uvm_mknod(int base_minor);
 int nvidia_modeset_modprobe(void);
@@ -92,16 +77,6 @@ int nvidia_nvswitch_mknod(int minor);
 
 #endif /* NV_LINUX */
 
-/*
- * Detect use of multiple kernel module instances. Use a single 
- * module instance unless instance != NV_MODULE_INSTANCE_NONE
- */
-static __inline__ int is_multi_module(int module_instance)
-{
-    return (module_instance != NV_MODULE_INSTANCE_NONE);
-}
-
-
 /*
  * Construct the device file name, based on 'minor'.  If an error
  * occurs, the nul terminator will be written to name[0].
@@ -109,8 +84,7 @@ static __inline__ int is_multi_module(int module_instance)
 static __inline__ void assign_device_file_name
 (
     char name[NV_MAX_CHARACTER_DEVICE_FILE_STRLEN],
-    int minor,
-    int module_instance
+    int minor
 )
 {
     int ret;
@@ -120,20 +94,12 @@ static __inline__ void assign_device_file_name
         goto fail;
     }
 
-    if (!is_multi_module(module_instance) && minor == NV_CTL_DEVICE_NUM)
+    if (minor == NV_CTL_DEVICE_NUM)
     {
         ret = snprintf(name,
                        NV_MAX_CHARACTER_DEVICE_FILE_STRLEN,
                        NV_CTRL_DEVICE_FILE_PATH);
     }
-    else if (is_multi_module(module_instance) && 
-             NV_FRONTEND_IS_CONTROL_DEVICE(minor))
-    {
-        ret = snprintf(name,
-                       NV_MAX_CHARACTER_DEVICE_FILE_STRLEN,
-                       NV_NMODULE_CTRL_DEVICE_FILE_PATH,
-                       module_instance);
-    }
     else
     {
         ret = snprintf(name,
